"""
Widget used for display and analysis of 2D and 3D image data.
Includes ROI plotting over time and image normalization.
"""

#from pyqtgraph_test.image_show_widget.image_show_basic_widget import ImageShowBasicWidget
